| Title: | An Interactive Wizard to Design, Build, and Deploy R Packages Demo Presentation |
|---|---|
| Description: | Design, build, and deploy R packages demo presentations by an interactive wizard. Set up unique title, logo and themes. Add personalized tabs exposing applicability. And deploy as a part of a package or an independent app. |
| Authors: | Rafal Urniaz [aut, cre]
|
| Maintainer: | Rafal Urniaz <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.1.3.11 |
| Built: | 2026-05-30 09:09:39 UTC |
| Source: | https://github.com/cran/ShinyWizard |
Function executes ShinyWizard builder when file location is not provided or project app when project zip file location is provided.
RunShinyWizard(loc = NULL, devMode = FALSE)RunShinyWizard(loc = NULL, devMode = FALSE)
loc |
file path to app file (*.zip), when NULL runs builder |
devMode |
when TRUE the developer mode is used. It means all tasks run by separate background jobs and the console is not blocked. It works by R Studio API so works only with R studio. It is mode only for development facilitate. Should not be used for production when compatibility with pure R is required. |
No return value, executes R shiny app
# Run to execute ShinyWizard builder RunShinyWizard() # Run to execute saved project as zip file RunShinyWizard("Path-to-project-file")# Run to execute ShinyWizard builder RunShinyWizard() # Run to execute saved project as zip file RunShinyWizard("Path-to-project-file")